@@ -2,5 +2,5 @@
 	library.dynam("Iso", pkg, lib)
 	ver <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), "Version")
         cat(paste(pkg, ver, "\n"))
-        cat("Note: This package now has a NAMSPACE.\n")
+        cat("Note: This package now has a NAMESPACE.\n")
 }
